# Simulate autotools detection for config generation
# This insanity is needed for autotools infected packages

include ( CheckIncludeFiles )
include ( CheckFunctionExists )
include ( CheckSymbolExists )

# Optional definitions (ifdef ifndef)
check_function_exists ( getexecname HAVE_GETEXECNAME )
check_function_exists ( getprogname HAVE_GETPROGNAME )

# Type checks
include ( CheckTypeSize )
check_type_size ( ptrdiff_t SIZEOF_PTRDIFF_T )
if ( SIZEOF_PTRDIFF_T )
  math ( EXPR BITSIZEOF_PTRDIFF_T "${SIZEOF_PTRDIFF_T} * 8" )
endif ()

set ( CMAKE_EXTRA_INCLUDE_FILES signal.h )
check_type_size ( sig_atomic_t SIZEOF_SIG_ATOMIC_T )
if ( SIZEOF_SIG_ATOMIC_T )
  math ( EXPR BITSIZEOF_SIG_ATOMIC_T "${SIZEOF_SIG_ATOMIC_T} * 8" )
endif ()

check_type_size ( size_t SIZEOF_SIZE_T )
if ( SIZEOF_SIZE_T )
  math ( EXPR BITSIZEOF_SIZE_T "${SIZEOF_SIZE_T} * 8" )
endif ()

set ( CMAKE_EXTRA_INCLUDE_FILES wchar.h )
check_type_size ( wchar_t SIZEOF_WCHAR_T )
if ( SIZEOF_WCHAR_T )
  set ( HAVE_WCHAR_T 1)
  math ( EXPR BITSIZEOF_WCHAR_T "${SIZEOF_WCHAR_T} * 8" )
endif ()

check_type_size ( wint_t SIZEOF_WINT_T )
if ( SIZEOF_WINT_T )
  math ( EXPR BITSIZEOF_WINT_T "${SIZEOF_WINT_T} * 8" )
endif ()

check_type_size ( "long long int" HAVE_LONG_LONG_INT )
check_type_size ( "unsigned long long int" HAVE_UNSIGNED_LONG_LONG_INT )
check_type_size ( _Bool HAVE__BOOL )
check_type_size ( sigset_t HAVE_SIGSET_T )

set ( HAVE_SIGNED_WCHAR_T 1 )
set ( HAVE_SIGNED_SIG_ATOMIC_T 1 )
set ( HAVE_SIGNED_WINT_T 1 )
set ( HAVE_SIGHANDLER_T 1 )
set ( HAVE_SIGINFO_T 1 )
set ( HAVE_SIGSET_T 1 )
set ( HAVE_TIMEZONE_T 0 )
set ( HAVE_TYPE_VOLATILE_SIG_ATOMIC_T 1 )
set ( HAVE_STRUCT_RANDOM_DATA 1 )
set ( HAVE_STRUCT_SIGACTION_SA_SIGACTION 1 )

include(TestBigEndian)
TEST_BIG_ENDIAN(IS_BIG_ENDIAN)
set ( WORDS_LITTLEENDIAN ${IS_BIG_ENDIAN} )

set ( STDC_HEADERS 1 )
set ( restrict "__restrict" )
set ( HAVE_MALLOC_POSIX 1 )
set ( HAVE_POSIX_OPENPT 1 )
set ( HAVE_POSIX_SIGNALBLOCKING 1 )

# Required definitions
macro(HAVE_HEADER HEADER VARIABLE)
  check_include_files ( ${HEADER} ${VARIABLE} )
  if ( NOT ${VARIABLE} )
    set ( ${VARIABLE} 0 )
  endif()
endmacro()

macro(HAVE_FUNCTION FUNCTION VARIABLE)
  check_function_exists ( ${FUNCTION} ${VARIABLE} )
  if ( NOT ${VARIABLE} )
    set ( ${VARIABLE} 0 )
  endif()
endmacro()

macro(HAVE_SYMBOL SYMBOL FILES VARIABLE)
  check_symbol_exists ( ${SYMBOL} ${FILES} ${VARIABLE} )
  if ( NOT ${VARIABLE} )
    set ( ${VARIABLE} 0 )
  endif()
endmacro()

if ( ${CMAKE_SYSTEM_NAME} STREQUAL "Linux" )
  set ( CMAKE_REQUIRED_DEFINITIONS "-D_GNU_SOURCE" )
endif()
have_symbol ( program_invocation_name "errno.h" HAVE_DECL_PROGRAM_INVOCATION_NAME)
have_symbol ( program_invocation_short_name "errno.h" HAVE_DECL_PROGRAM_INVOCATION_SHORT_NAME )

if (ANDROID)
  set ( HAVE_VAR___PROGNAME 1 )
elseif ( MSVC )
  set ( HAVE_DECL___ARGV 1 )
else()
  set ( HAVE_VAR___PROGNAME 0 )
  set ( HAVE_DECL___ARGV 0 )
endif()

# Header checks
have_header ( alloca.h HAVE_ALLOCA_H )
have_header ( dlfcn.h HAVE_DLFCN_H )
have_header ( inttypes.h HAVE_INTTYPES_H )
have_header ( mach-o/dyld.h HAVE_MACH_O_DYLD_H )
have_header ( limits.h HAVE_LIMITS_H )
have_header ( memory.h HAVE_MEMORY_H )
have_header ( os.h HAVE_OS_H )
have_header ( random.h HAVE_RANDOM_H )
have_header ( search.h HAVE_SEARCH_H )
have_header ( stdint.h HAVE_STDINT_H )
have_header ( stdlib.h HAVE_STDLIB_H )
have_header ( strings.h HAVE_STRINGS_H )
have_header ( string.h HAVE_STRING_H )
have_header ( sys/bitypes.h HAVE_SYS_BITYPES_H )
have_header ( sys/inttypes.h HAVE_SYS_INTTYPES_H )
have_header ( sys/loadavg.h HAVE_SYS_LOADAVG_H )
have_header ( sys/param.h HAVE_SYS_PARAM_H )
have_header ( sys/socket.h HAVE_SYS_SOCKET_H )
have_header ( sys/stat.h HAVE_SYS_STAT_H )
have_header ( sys/time.h HAVE_SYS_TIME_H )
have_header ( sys/types.h HAVE_SYS_TYPES_H )
have_header ( unistd.h HAVE_UNISTD_H )
have_header ( wchar.h HAVE_WCHAR_H )
have_header ( winsock2.h HAVE_WINSOCK2_H )

# Function checks
have_function ( atoll HAVE_ATOLL )
have_function ( canonicalize_file_name HAVE_CANONICALIZE_FILE_NAME )
have_function ( chown HAVE_CHOWN )
have_function ( dcgettext HAVE_DCGETTEXT )
have_function ( gettext HAVE_GETTEXT )
have_function ( iconv HAVE_ICONV )
have_function ( lstat HAVE_LSTAT )
have_function ( mbrtowc HAVE_MBRTOWC )
have_function ( mbsinit HAVE_MBSINIT )
have_function ( memmove HAVE_MEMMOVE )
have_function ( atoll HAVE_ATOLL )
have_function ( chown HAVE_CHOWN )
have_function ( dprintf HAVE_DPRINTF )
have_function ( dup2 HAVE_DUP2 )
have_function ( dup3 HAVE_DUP3 )
have_function ( endusershell HAVE_ENDUSERSHELL )
have_function ( environ HAVE_ENVIRON )
have_function ( euidaccess HAVE_EUIDACCESS )
have_function ( explicit_bzero HAVE_EXPLICIT_BZERO )
have_function ( faccessat HAVE_FACCESSAT )
have_function ( fchdir HAVE_FCHDIR )
have_function ( fchmodat HAVE_FCHMODAT )
have_function ( fchownat HAVE_FCHOWNAT )
have_function ( fcntl HAVE_FCNTL )
have_function ( fdatasync HAVE_FDATASYNC )
have_function ( ffsl HAVE_FFSL )
have_function ( ffsll HAVE_FFSLL )
have_function ( fpurge HAVE_FPURGE )
have_function ( fseeko HAVE_FSEEKO )
have_function ( fstatat HAVE_FSTATAT )
have_function ( fsync HAVE_FSYNC )
have_function ( ftello HAVE_FTELLO )
have_function ( ftruncate HAVE_FTRUNCATE )
have_function ( futimens HAVE_FUTIMENS )
have_function ( getcwd HAVE_GETCWD )
have_function ( getdelim HAVE_GETDELIM )
have_function ( getdomainname HAVE_GETDOMAINNAME )
have_function ( canonicalize_file_name HAVE_CANONICALIZE_FILE_NAME )
have_function ( getdtablesize HAVE_GETDTABLESIZE )
have_function ( getgroups HAVE_GETGROUPS )
have_function ( gethostname HAVE_GETHOSTNAME )
have_function ( getline HAVE_GETLINE )
have_function ( getloadavg HAVE_GETLOADAVG )
have_function ( getlogin HAVE_GETLOGIN )
have_function ( getlogin_r HAVE_GETLOGIN_R )
have_function ( getpagesize HAVE_GETPAGESIZE )
have_function ( getpass HAVE_GETPASS )
have_function ( getsubopt HAVE_GETSUBOPT )
have_function ( getusershell HAVE_GETUSERSHELL )
have_function ( grantpt HAVE_GRANTPT )
have_function ( group_member HAVE_GROUP_MEMBER )
have_function ( initstate HAVE_INITSTATE )
have_function ( initstate_r HAVE_INITSTATE_R )
have_function ( lchmod HAVE_LCHMOD )
have_function ( lchown HAVE_LCHOWN )
have_function ( link HAVE_LINK )
have_function ( linkat HAVE_LINKAT )
have_function ( lseek HAVE_LSEEK )
have_function ( lstat HAVE_LSTAT )
have_function ( mbslen HAVE_MBSLEN )
have_function ( mbtowc HAVE_MBTOWC )
have_function ( memrchr HAVE_MEMRCHR )
have_function ( memmem HAVE_MEMMEM )
have_function ( mempcpy HAVE_MEMPCPY )
have_function ( mkdirat HAVE_MKDIRAT )
have_function ( mkdtemp HAVE_MKDTEMP )
have_function ( mkfifo HAVE_MKFIFO )
have_function ( mkfifoat HAVE_MKFIFOAT )
have_function ( mknod HAVE_MKNOD )
have_function ( mknodat HAVE_MKNODAT )
have_function ( mkostemp HAVE_MKOSTEMP )
have_function ( mkostemps HAVE_MKOSTEMPS )
have_function ( mkstemp HAVE_MKSTEMP )
have_function ( mkstemps HAVE_MKSTEMPS )
have_function ( nanosleep HAVE_NANOSLEEP )
have_function ( openat HAVE_OPENAT )
have_function ( pclose HAVE_PCLOSE )
have_function ( pipe HAVE_PIPE )
have_function ( pipe2 HAVE_PIPE2 )
have_function ( popen HAVE_POPEN )
have_function ( pread HAVE_PREAD )
have_function ( pthread_sigmask HAVE_PTHREAD_SIGMASK )
have_function ( ptsname HAVE_PTSNAME )
have_function ( ptsname_r HAVE_PTSNAME_R )
have_function ( pwrite HAVE_PWRITE )
have_function ( qsort_r HAVE_QSORT_R )
have_function ( raise HAVE_RAISE )
have_function ( random HAVE_RANDOM )
have_function ( random_r HAVE_RANDOM_R )
have_function ( rawmemchr HAVE_RAWMEMCHR )
have_function ( readlink HAVE_READLINK )
have_function ( readlinkat HAVE_READLINKAT )
have_function ( reallocarray HAVE_REALLOCARRAY )
have_function ( realpath HAVE_REALPATH )
have_function ( renameat HAVE_RENAMEAT )
have_function ( rmdir HAVE_RMDIR )
have_function ( rpmatch HAVE_RPMATCH )
have_function ( secure_getenv HAVE_SECURE_GETENV )
have_function ( setenv HAVE_SETENV )
have_function ( sethostname HAVE_SETHOSTNAME )
have_function ( setlocale HAVE_SETLOCALE )
have_function ( setstate HAVE_SETSTATE )
have_function ( setstate_r HAVE_SETSTATE_R )
have_function ( setusershell HAVE_SETUSERSHELL )
have_function ( sigaction HAVE_SIGACTION )
have_function ( sigaddset HAVE_SIGADDSET )
have_function ( sigdelset HAVE_SIGDELSET )
have_function ( sigemptyset HAVE_SIGEMPTYSET )
have_function ( sigfillset HAVE_SIGFILLSET )
have_function ( sigismember HAVE_SIGISMEMBER )
have_function ( sigpending HAVE_SIGPENDING )
have_function ( sigprocmask HAVE_SIGPROCMASK )
have_function ( sleep HAVE_SLEEP )
have_function ( snprintf HAVE_SNPRINTF )
have_function ( srandom_r HAVE_SRANDOM_R )
have_function ( stat HAVE_STAT )
have_function ( stpcpy HAVE_STPCPY )
have_function ( stpncpy HAVE_STPNCPY )
have_function ( strcasestr HAVE_STRCASESTR )
have_function ( strchrnul HAVE_STRCHRNUL )
have_function ( strdup HAVE_STRDUP )
have_function ( strerror_r HAVE_STRERROR_R )
have_function ( strncat HAVE_STRNCAT )
have_function ( strndup HAVE_STRNDUP )
have_function ( strnlen HAVE_STRNLEN )
have_function ( strpbrk HAVE_STRSEP )
have_function ( strptime HAVE_STRPTIME )
have_function ( strsep HAVE_STRSEP )
have_function ( strsignal HAVE_STRSIGNAL )
have_function ( strtod HAVE_STRTOD )
have_function ( strtok_r HAVE_STRTOK_R )
have_function ( strtold HAVE_STRTOLD )
have_function ( strtoll HAVE_STRTOLL )
have_function ( strtoull HAVE_STRTOULL )
have_function ( strverscmp HAVE_STRVERSCMP )
have_function ( symlink HAVE_SYMLINK )
have_function ( symlinkat HAVE_SYMLINKAT )
have_function ( timegm HAVE_TIMEGM )
have_function ( tzset HAVE_TZSET )
have_function ( tmpfile HAVE_TMPFILE )
have_function ( tsearch HAVE_TSEARCH )
have_function ( ttyname_r HAVE_TTYNAME_R )
have_function ( unlink HAVE_UNLINK )
have_function ( unlinkat HAVE_UNLINKAT )
have_function ( unlockpt HAVE_UNLOCKPT )
have_function ( unsetenv HAVE_UNSETENV )
have_function ( usleep HAVE_USLEEP )
have_function ( utimensat HAVE_UTIMENSAT )
have_function ( vasprintf HAVE_VASPRINTF )
have_function ( vdprintf HAVE_VDPRINTF )
have_function ( vsnprintf HAVE_VSNPRINTF )
have_function ( wcrtomb HAVE_WCRTOMB )
have_function ( _Exit HAVE__EXIT )
have_function ( _NSGetExecutablePath HAVE__NSGETEXECUTABLEPATH )

# Symbols
have_symbol ( alloca "alloca.h" HAVE_ALLOCA )
have_symbol ( clearerr_unlocked "stdio.h" HAVE_DECL_CLEARERR_UNLOCKED )
have_symbol ( feof_unlocked "stdio.h" HAVE_DECL_FEOF_UNLOCKED )
have_symbol ( ferror_unlocked "stdio.h" HAVE_DECL_FERROR_UNLOCKED )
have_symbol ( fflush_unlocked "stdio.h" HAVE_DECL_FFLUSH_UNLOCKED )
have_symbol ( fgets_unlocked "stdio.h" HAVE_DECL_FGETS_UNLOCKED )
have_symbol ( fputc_unlocked "stdio.h" HAVE_DECL_FPUTC_UNLOCKED )
have_symbol ( fputs_unlocked "stdio.h" HAVE_DECL_FPUTS_UNLOCKED )
have_symbol ( fread_unlocked "stdio.h" HAVE_DECL_FREAD_UNLOCKED )
have_symbol ( fwrite_unlocked "stdio.h" HAVE_DECL_FWRITE_UNLOCKED )
have_symbol ( getchar_unlocked "stdio.h" HAVE_DECL_GETCHAR_UNLOCKED )
have_symbol ( getc_unlocked "stdio.h" HAVE_DECL_GETC_UNLOCKED )
have_symbol ( program_invocation_name "stdio.h" HAVE_DECL_PROGRAM_INVOCATION_NAME )
have_symbol ( program_invocation_short_name "stdio.h" HAVE_DECL_PROGRAM_INVOCATION_SHORT_NAME )
have_symbol ( putchar_unlocked "stdio.h" HAVE_DECL_PUTCHAR_UNLOCKED )
have_symbol ( putc_unlocked "stdio.h" HAVE_DECL_PUTC_UNLOCKED )
have_symbol ( strerror_r "string.h" HAVE_DECL_STRERROR_R )
have_symbol ( strsignal "string.h" HAVE_DECL_STRSIGNAL )
have_symbol ( memmem "string.h" HAVE_DECL_MEMMEM )
have_symbol ( memrchr "string.h" HAVE_DECL_MEMRCHR )
have_symbol ( strdup "string.h" HAVE_DECL_STRDUP )
have_symbol ( strndup "string.h" HAVE_DECL_STRNDUP )
have_symbol ( strnlen "string.h" HAVE_DECL_STRNLEN )
have_symbol ( strtok_r "string.h" HAVE_DECL_STRTOK_R )
have_symbol ( localtime_r "time.h" HAVE_DECL_LOCALTIME_R )
have_symbol ( environ "unistd.h" HAVE_DECL_ENVIRON )
have_symbol ( getc_unlocked "fp.h" HAVE_GETC_UNLOCKED )
have_symbol ( getcwd "unistd.h" HAVE_GETCWD )
have_symbol ( fchdir "unistd.h" HAVE_DECL_FCHDIR )
have_symbol ( fdatasync "unistd.h" HAVE_DECL_FDATASYNC )
have_symbol ( getdomainname "unistd.h" HAVE_DECL_GETDOMAINNAME )
have_symbol ( getlogin "unistd.h" HAVE_DECL_GETLOGIN )
have_symbol ( getlogin_r "unistd.h" HAVE_DECL_GETLOGIN_R )
have_symbol ( getpagesize "unistd.h" HAVE_DECL_GETPAGESIZE )
have_symbol ( getusershell "unistd.h" HAVE_DECL_GETUSERSHELL )
have_symbol ( sethostname "unistd.h" HAVE_DECL_SETHOSTNAME )
have_symbol ( truncate "unistd.h" HAVE_DECL_TRUNCATE )
have_symbol ( ttyname_r "unistd.h" HAVE_DECL_TTYNAME_R )

have_symbol ( nl_langinfo "langinfo.h" HAVE_LANGINFO_CODESET )
have_symbol ( mbstate_t "wchar.h" HAVE_MBSTATE_T )
have_symbol ( fpurge "stdio.h" HAVE_DECL_FPURGE )
have_symbol ( fseeko "stdio.h" HAVE_DECL_FSEEKO )
have_symbol ( ftello "stdio.h" HAVE_DECL_FTELLO )
have_symbol ( getdelim "stdio.h" HAVE_DECL_GETDELIM )
have_symbol ( getline "stdio.h" HAVE_DECL_GETLINE )
have_symbol ( obstack_printf "stdio.h" HAVE_DECL_OBSTACK_PRINTF )
have_symbol ( snprintf "stdio.h" HAVE_DECL_SNPRINTF )
have_symbol ( vsnprintf "stdio.h" HAVE_DECL_VSNPRINTF )
have_symbol ( getloadavg "stdlib.h" HAVE_DECL_GETLOADAVG )
have_symbol ( initstate "stdlib.h" HAVE_DECL_INITSTATE )
have_symbol ( setstate "stdlib.h" HAVE_DECL_SETSTATE )
have_symbol ( setenv "stdlib.h" HAVE_DECL_SETENV )
have_symbol ( unsetenv "stdlib.h" HAVE_DECL_UNSETENV )

# Other
set ( USE_MBSTATE_T 1 )
set ( BROKEN_WCHAR_H 0 )
set ( UNISTD_H_HAVE_WINSOCK2_H_AND_USE_SOCKETS 0 )
set ( _DARWIN_USE_64_BIT_INODE 1 )
set ( _GL_ASYNC_SAFE "" )
set ( _NETBSD_SOURCE 1 )
set ( _UNUSED_PARAMETER_ "_GL_UNUSED" )
set ( _USE_STD_STAT 1 )
set ( HAVE_VISIBILITY 1 )
set ( HAVE_STRUCT_STAT_ST_ATIM_TV_NSEC 1 )
set ( HAVE_WORKING_O_NOATIME 1 )
set ( HAVE_WORKING_O_NOFOLLOW 1 )
set ( ICONV_CONST "" )
set ( INSTALLPREFIX "" )
set ( LSTAT_FOLLOWS_SLASHED_SYMLINK 1 )
set ( MALLOC_0_IS_NONNULL 1 )
set ( PACKAGE_BUGREPORT "" )
set ( PACKAGE "libiconv" )
set ( PACKAGE_NAME "libiconv" )
set ( PACKAGE_STRING "libiconv ${DIST_VERSION}" )
set ( PACKAGE_TARNAME "libiconv" )
set ( PACKAGE_URL "" )
set ( PACKAGE_VERSION "${DIST_VERSION}" )
set ( TYPEOF_STRUCT_STAT_ST_ATIM_IS_STRUCT_TIMESPEC 1 )
set ( USER_LABEL_PREFIX "" ) 
set ( USE_UNLOCKED_IO 1 )
set ( VERSION "${DIST_VERSION}" )
set ( REPLACE_STRERROR_0 1 )
set ( STRERROR_R_CHAR_P 0 )
set ( PTRDIFF_T_SUFFIX l )
set ( SIG_ATOMIC_T_SUFFIX 1 )
set ( SIZE_T_SUFFIX ul )
set ( FUNC_REALPATH_WORKS 1 )

if ( APPLE )
  set ( HAVE_CFLOCALECOPYCURRENT 1 )
  set ( HAVE_CFPREFERENCESCOPYAPPVALUE 1 )
  set ( HAVE__NSGETEXECUTABLEPATH 1 )
endif ()

# GNULIB settings
set ( INCLUDE_NEXT "include_next" )
set ( PRAGMA_SYSTEM_HEADER "#pragma GCC system_header" )
set ( PRAGMA_COLUMNS "" )
set ( GUARD_PREFIX "GL" )

set ( GNULIB_CANONICALIZE_LGPL 1 )
set ( GNULIB_MSVC_NOTHROW 1 )
set ( GNULIB_STRERROR_R_POSIX 0)
set ( GNULIB_POSIXCHECK 0 )

set ( NEXT_STDIO_H "<stdio.h>" )
set ( GNULIB_RENAMEAT 0 )
set ( GNULIB_PERROR 0 )
set ( GNULIB_REMOVE 0 )
set ( GNULIB_RENAME 0 )
set ( GNULIB_DPRINTF 0 )
set ( REPLACE_DPRINTF 0 )
set ( GNULIB_FCLOSE 0 )
set ( REPLACE_FCLOSE 0 )
set ( GNULIB_FDOPEN 0 )
set ( REPLACE_FDOPEN 0 )
set ( GNULIB_FFLUSH 0 )
set ( REPLACE_FFLUSH 0 )
set ( GNULIB_FGETC 1 )
set ( REPLACE_STDIO_READ_FUNCS 0 )
set ( GNULIB_STDIO_H_NONBLOCKING 0 )
set ( GNULIB_FGETS 1 )
set ( GNULIB_FOPEN 0 )
set ( REPLACE_FOPEN 0 )
set ( GNULIB_FPRINTF_POSIX 0 )
set ( GNULIB_FPRINTF 1 )
set ( REPLACE_FPRINTF 0 )
set ( REPLACE_STDIO_WRITE_FUNCS 0 )
set ( GNULIB_STDIO_H_SIGPIPE 1 )
set ( GNULIB_VFPRINTF_POSIX 0 )
set ( GNULIB_FPURGE 0 )
set ( REPLACE_FPURGE 0 )
set ( GNULIB_FPUTC 1 )
set ( GNULIB_FPUTS 1 )
set ( GNULIB_FREAD 1 )
set ( GNULIB_FREOPEN 0 )
set ( REPLACE_FREOPEN 0 )
set ( GNULIB_FSCANF 1 )
set ( GNULIB_FSEEK 0 )
set ( REPLACE_FSEEK 0 )
set ( GNULIB_FSEEKO 0 )
set ( REPLACE_FSEEKO 0 )
set ( GNULIB_FTELL 0 )
set ( REPLACE_FTELL 0 )
set ( GNULIB_FTELLO 0 )
set ( REPLACE_FTELLO 0 )
set ( GNULIB_FWRITE 1 )
set ( GNULIB_GETC 1 )
set ( GNULIB_GETCHAR 1 )
set ( GNULIB_GETDELIM 0 )
set ( REPLACE_GETDELIM 0 )
set ( GNULIB_GETLINE 0 )
set ( REPLACE_GETLINE 0 )
set ( GNULIB_OBSTACK_PRINTF 0 )
set ( GNULIB_OBSTACK_PRINTF_POSIX 0 )
set ( REPLACE_OBSTACK_PRINTF 0 )
set ( GNULIB_PCLOSE 0 )
set ( GNULIB_PERROR 0 )
set ( REPLACE_PERROR 0 )
set ( GNULIB_POPEN 0 )
set ( REPLACE_POPEN 0 )
set ( GNULIB_PRINTF_POSIX 0 )
set ( GNULIB_PRINTF 1 )
set ( REPLACE_PRINTF 0 )
set ( ASM_SYMBOL_PREFIX "\"\"" )
set ( GNULIB_PUTC 1 )
set ( GNULIB_PUTCHAR 1 )
set ( GNULIB_PUTS 1 )
set ( GNULIB_REMOVE 0 )
set ( REPLACE_REMOVE 0 )
set ( GNULIB_RENAME 0 )
set ( REPLACE_RENAME 0 )
set ( GNULIB_RENAMEAT 0 )
set ( REPLACE_RENAMEAT 0 )
set ( GNULIB_SCANF 1 )
set ( GNULIB_SNPRINTF 0 )
set ( REPLACE_SNPRINTF 0 )
set ( GNULIB_SPRINTF_POSIX 0 )
set ( REPLACE_SPRINTF 0 )
set ( GNULIB_TMPFILE 0 )
set ( REPLACE_TMPFILE 0 )
set ( GNULIB_VASPRINTF 0 )
set ( REPLACE_VASPRINTF 0 )
set ( GNULIB_VDPRINTF 0 )
set ( REPLACE_VDPRINTF 0 )
set ( GNULIB_VFPRINTF 1 )
set ( REPLACE_VFPRINTF 0 )
set ( GNULIB_VFSCANF 0 )
set ( GNULIB_VPRINTF_POSIX 0 )
set ( GNULIB_VPRINTF 1 )
set ( REPLACE_VPRINTF 0 )
set ( GNULIB_VSCANF 0 )
set ( GNULIB_VSNPRINTF 0 )
set ( REPLACE_VSNPRINTF 0 )
set ( GNULIB_VSPRINTF_POSIX 0 )
set ( REPLACE_VSPRINTF 0 )

set ( NEXT_FCNTL_H "<fcntl.h>" )
set ( GNULIB_OPEN 0 )
set ( GNULIB_FCNTL 0 )
set ( REPLACE_FCNTL 0 )
set ( REPLACE_OPEN 0 )
set ( GNULIB_OPENAT 0 )
set ( REPLACE_OPENAT 0 )
set ( GNULIB_NONBLOCKING 0 )

set ( NEXT_LIMITS_H "<limits.h>" )

set ( NEXT_SIGNAL_H "<signal.h>" )
set ( GNULIB_PTHREAD_SIGMASK 0 )
set ( GNULIB_SIGNAL_H_SIGPIPE 1 )
set ( GNULIB_PTHREAD_SIGMASK 0 )
set ( REPLACE_PTHREAD_SIGMASK 0 )
set ( GNULIB_RAISE 1 )
set ( REPLACE_RAISE 0 )
set ( GNULIB_SIGPROCMASK 1 )
set ( GNULIB_SIGACTION 0 )

set ( NEXT_STDLIB_H "<stdlib.h>" )
set ( GNULIB_SYSTEM_POSIX 0 )
set ( GNULIB_GETLOADAVG 0 )
set ( GNULIB_RANDOM_R 0 )
set ( REPLACE_RANDOM_R 0 )
set ( GNULIB_MKSTEMP 0 )
set ( GNULIB_MKSTEMPS 0 )
set ( GNULIB_MKOSTEMP 0 )
set ( GNULIB_MKOSTEMPS 0 )
set ( GNULIB_GETSUBOPT 0 )
set ( GNULIB__EXIT 0 )
set ( GNULIB_ATOLL 0 )
set ( GNULIB_CALLOC_POSIX 0 )
set ( REPLACE_CALLOC 0 )
set ( GNULIB_CANONICALIZE_FILE_NAME 1 )
set ( REPLACE_CANONICALIZE_FILE_NAME 0 )
set ( GNULIB_GETSUBOPT 0 )
set ( GNULIB_GRANTPT 0 )
set ( GNULIB_MALLOC_POSIX 1 )
set ( REPLACE_MALLOC 0 )
set ( GNULIB_MBTOWC 0 )
set ( REPLACE_MBTOWC 0 )
set ( GNULIB_MKDTEMP 0 )
set ( REPLACE_MKSTEMP 0 )
set ( GNULIB_POSIX_OPENPT 0 )
set ( GNULIB_PTSNAME 0 )
set ( REPLACE_PTSNAME 0 )
set ( GNULIB_PTSNAME_R 0 )
set ( REPLACE_PTSNAME_R 0 )
set ( GNULIB_PUTENV 0 )
set ( REPLACE_PUTENV 0 )
set ( GNULIB_QSORT_R 0 )
set ( REPLACE_QSORT_R 0 )
set ( GNULIB_RANDOM 0 )
set ( REPLACE_RANDOM 0 )
set ( REPLACE_INITSTATE 0 )
set ( REPLACE_SETSTATE 0 )
set ( GNULIB_REALLOC_POSIX 0 )
set ( REPLACE_REALLOC 0 )
set ( GNULIB_REALLOCARRAY 0 )
set ( GNULIB_REALPATH 1 )
set ( REPLACE_REALPATH 0 )
set ( GNULIB_RPMATCH 0 )
set ( GNULIB_SECURE_GETENV 0 )
set ( GNULIB_SETENV 0 )
set ( REPLACE_SETENV 0 )
set ( GNULIB_STRTOD 0 )
set ( REPLACE_STRTOD 0 )
set ( GNULIB_STRTOLD 0 )
set ( REPLACE_STRTOLD 0 )
set ( GNULIB_STRTOLL 0 )
set ( GNULIB_STRTOULL 0 )
set ( GNULIB_UNLOCKPT 0 )
set ( GNULIB_UNSETENV 0 )
set ( REPLACE_UNSETENV 0 )
set ( GNULIB_WCTOMB 0 )
set ( REPLACE_WCTOMB 0 )

set ( NEXT_STRING_H "<string.h>" )
set ( GNULIB_MBSLEN 0 )
set ( GNULIB_STRSIGNAL 0 )
set ( GNULIB_EXPLICIT_BZERO 0 )
set ( GNULIB_FFSL 0 )
set ( GNULIB_FFSLL 0 )
set ( GNULIB_MEMCHR 0 )
set ( REPLACE_MEMCHR 0 )
set ( GNULIB_MEMMEM 0 )
set ( REPLACE_MEMMEM 0 )
set ( GNULIB_MEMPCPY 0 )
set ( GNULIB_MEMRCHR 0 )
set ( GNULIB_RAWMEMCHR 0 )
set ( GNULIB_STPCPY 0 )
set ( GNULIB_STPNCPY 0 )
set ( REPLACE_STPNCPY 0 )
set ( GNULIB_STRCHRNUL 0 )
set ( REPLACE_STRCHRNUL 0 )
set ( GNULIB_STRDUP 0 )
set ( REPLACE_STRDUP 0 )
set ( GNULIB_STRNCAT 0 )
set ( REPLACE_STRNCAT 0 )
set ( GNULIB_STRNDUP 0 )
set ( REPLACE_STRNDUP 0 )
set ( GNULIB_STRNLEN 0 )
set ( REPLACE_STRNLEN 0 )
set ( GNULIB_STRPBRK 0 )
set ( GNULIB_STRSEP 0 )
set ( GNULIB_STRSTR 0 )
set ( REPLACE_STRSTR 0 )
set ( GNULIB_STRCASESTR 0 )
set ( REPLACE_STRCASESTR 0 )
set ( GNULIB_STRTOK_R 0 )
set ( REPLACE_STRTOK_R 0 )
set ( UNDEFINE_STRTOK_R 0 )
set ( GNULIB_MBSLEN 0 )
set ( GNULIB_MBSNLEN 0 )
set ( GNULIB_MBSCHR 0 )
set ( GNULIB_MBSRCHR 0 )
set ( GNULIB_MBSSTR 0 )
set ( GNULIB_MBSCASECMP 0 )
set ( GNULIB_MBSNCASECMP 0 )
set ( GNULIB_MBSPCASECMP 0 )
set ( GNULIB_MBSCASESTR 0 )
set ( GNULIB_MBSCSPN 0 )
set ( GNULIB_MBSPBRK 0 )
set ( GNULIB_MBSSPN 0 )
set ( GNULIB_MBSSEP 0 )
set ( GNULIB_MBSTOK_R 0 )
set ( GNULIB_STRERROR 1 )
set ( REPLACE_STRERROR 0 )
set ( GNULIB_STRERROR_R 0 )
set ( REPLACE_STRERROR_R 0 )
set ( GNULIB_STRSIGNAL 0 )
set ( REPLACE_STRSIGNAL 0 )
set ( GNULIB_STRVERSCMP 0 )

set ( NEXT_TIME_H "<time.h>" )
set ( TIME_H_DEFINES_STRUCT_TIMESPEC 1 )
set ( SYS_TIME_H_DEFINES_STRUCT_TIMESPEC 0 )
set ( PTHREAD_H_DEFINES_STRUCT_TIMESPEC 0 )
set ( UNISTD_H_DEFINES_STRUCT_TIMESPEC 0 )
set ( GNULIB_PORTCHECK 0 )
set ( GNULIB_NANOSLEEP 0 )
set ( REPLACE_NANOSLEEP "GNULIB_PORTCHECK" )
set ( GNULIB_TZSET 0 )
set ( REPLACE_TZSET "GNULIB_PORTCHECK" )
set ( GNULIB_MKTIME 0 )
set ( REPLACE_MKTIME "GNULIB_PORTCHECK" )
set ( GNULIB_TIME_R 0 )
set ( REPLACE_LOCALTIME_R "GNULIB_PORTCHECK" )
set ( GNULIB_LOCALTIME 0 )
set ( REPLACE_LOCALTIME 0 )
set ( REPLACE_GMTIME 0 )
set ( GNULIB_STRPTIME 0 )
set ( GNULIB_CTIME 0 )
set ( REPLACE_CTIME "GNULIB_PORTCHECK" )
set ( GNULIB_STRFTIME 0 )
set ( REPLACE_STRFTIME "GNULIB_PORTCHECK" )
set ( GNULIB_TIME_RZ 0 )
set ( GNULIB_TIMEGM 0 )
set ( REPLACE_TIMEGM "GNULIB_PORTCHECK" )

set ( NEXT_UNISTD_H "<unistd.h>" )
set ( GNULIB_GETHOSTNAME 0 )
set ( UNISTD_H_HAVE_WINSOCK2_H 0 )
set ( GNULIB_UNLINK 0 )
set ( GNULIB_SYMLINKAT 0 )
set ( GNULIB_UNLINKAT 0 )
set ( GNULIB_CHDIR 0 )
set ( GNULIB_GETCWD 0 )
set ( GNULIB_RMDIR 0 )
set ( GNULIB_CLOSE 0 )
set ( GNULIB_DUP 0 )
set ( GNULIB_DUP2 0 )
set ( GNULIB_ISATTY 0 )
set ( GNULIB_LSEEK 0 )
set ( GNULIB_READ 1 )
set ( GNULIB_UNLINK 0 )
set ( GNULIB_WRITE 0 )
set ( GNULIB_GETDOMAINNAME 0 )
set ( GNULIB_GETHOSTNAME 0 )
set ( GNULIB_FCHOWNAT 0 )
set ( WINDOWS_64_BIT_OFF_T 0 )
set ( GNULIB_READLINK 1 )
set ( GNULIB_READLINKAT 0 )
set ( GNULIB_PREAD 0 )
set ( GNULIB_PWRITE 0 )
set ( GNULIB_UNISTD_H_GETOPT 0 )
set ( GNULIB_CHOWN 0 )
set ( REPLACE_CHOWN 0 )
set ( GNULIB_CLOSE 0 )
set ( REPLACE_CLOSE 0 )
set ( REPLACE_DUP 0 )
set ( REPLACE_DUP2 0 )
set ( GNULIB_DUP3 0 )
set ( GNULIB_ENVIRON 1 )
set ( GNULIB_EUIDACCESS 0 )
set ( GNULIB_FACCESSAT 0 )
set ( REPLACE_FACCESSAT 0 )
set ( GNULIB_FCHDIR 0 )
set ( GNULIB_FCHOWNAT 0 )
set ( REPLACE_FCHOWNAT 0 )
set ( GNULIB_FDATASYNC 0 )
set ( GNULIB_FSYNC 0 )
set ( GNULIB_FTRUNCATE 0 )
set ( REPLACE_FTRUNCATE 0 )
set ( GNULIB_GETCWD 0 )
set ( REPLACE_GETCWD 0 )
set ( REPLACE_GETDOMAINNAME 0 )
set ( GNULIB_GETDTABLESIZE 0 )
set ( REPLACE_GETDTABLESIZE 0 )
set ( GNULIB_GETGROUPS 0 )
set ( REPLACE_GETGROUPS 0 )
set ( GNULIB_GETLOGIN 0 )
set ( GNULIB_GETLOGIN_R 0 )
set ( REPLACE_GETLOGIN_R 0 )
set ( GNULIB_GETPAGESIZE 0 )
set ( REPLACE_GETPAGESIZE 0 )
set ( GNULIB_GETPASS 0 )
set ( REPLACE_GETPASS 0 )
set ( GNULIB_GETUSERSHELL 0 )
set ( GNULIB_GROUP_MEMBER 0 )
set ( GNULIB_ISATTY 0 )
set ( REPLACE_ISATTY 0 )
set ( GNULIB_LCHOWN 0 )
set ( REPLACE_LCHOWN 0 )
set ( GNULIB_LINK 0 )
set ( REPLACE_LINK 0 )
set ( GNULIB_LINKAT 0 )
set ( REPLACE_LINKAT 0 )
set ( GNULIB_LSEEK 0 )
set ( REPLACE_LSEEK 0 )
set ( GNULIB_PIPE 0 )
set ( GNULIB_PIPE2 0 )
set ( GNULIB_PREAD 0 )
set ( REPLACE_PREAD 0 )
set ( REPLACE_PWRITE 0 )
set ( REPLACE_READ 0 )
set ( REPLACE_READLINK 0 )
set ( GNULIB_READLINKAT 0 )
set ( GNULIB_SETHOSTNAME 0 )
set ( GNULIB_SLEEP 0 )
set ( REPLACE_SLEEP 0 )
set ( GNULIB_SYMLINK 0 )
set ( REPLACE_SYMLINK 0 )
set ( REPLACE_SYMLINKAT 0 )
set ( GNULIB_TRUNCATE 0 )
set ( REPLACE_TRUNCATE 0 )
set ( GNULIB_TTYNAME_R 0 )
set ( REPLACE_TTYNAME_R 0 )
set ( REPLACE_UNLINK 0 )
set ( REPLACE_UNLINKAT 0 )
set ( GNULIB_USLEEP 0 )
set ( REPLACE_USLEEP 0 )
set ( REPLACE_WRITE 0 )

